@@ -15,6 +15,7 @@
 #
 
 import asyncio
+import json
 import logging
 
 from aiohomekit.controller.pairing import AbstractPairing
@@ -261,7 +262,7 @@ class IpPairing(AbstractPairing):
             aid = characteristic[0]
             iid = characteristic[1]
             value = characteristic[2]
-            characteristics_set.add("{a}.{i}".format(a=aid, i=iid))
+            characteristics_set.add(f"{aid}.{iid}")
             data.append({"aid": aid, "iid": iid, "value": value})
         data = {"characteristics": data}
 
@@ -392,7 +393,7 @@ class IpPairing(AbstractPairing):
         elif permissions == "Admin":
             permissions = TLV.kTLVType_Permission_AdminUser
         else:
-            raise RuntimeError("Unknown permission: {p}".format(p=permissions))
+            raise RuntimeError(f"Unknown permission: {permissions}")
 
         request_tlv = [
             (TLV.kTLVType_State, TLV.M1),
@@ -453,3 +454,18 @@ class IpPairing(AbstractPairing):
             raise AuthenticationError("Remove pairing failed: missing authentication")
 
         raise UnknownError("Remove pairing failed: unknown error")
+
+    async def image(self, accessory, width, height):
+        resp = await self.connection.post(
+            "/resource",
+            content_type="application/json",
+            body=json.dumps(
+                {
+                    "aid": accessory,
+                    "resource-type": "image",
+                    "image-width": width,
+                    "image-height": height,
+                }
+            ).encode("utf-8"),
+        )
+        return resp.body
